rm(list=ls())


################################################################################
################### Figure 3b  and s2b #########################################
################################################################################


#install.packages(rstudioapi)
library("rstudioapi")

#install.packages("ggplot2")
library(ggplot2)


setwd(dirname(getActiveDocumentContext()$path))
getwd

landings<-read.table("landings.txt", header = T)

## Summarizes data.
## Gives count, mean, standard deviation, standard error of the mean, and confidence interval (default 95%).
##   data: a data frame.
##   measurevar: the name of a column that contains the variable to be summarized
##   groupvars: a vector containing names of columns that contain grouping variables
##   na.rm: a boolean that indicates whether to ignore NA's
##   conf.interval: the percent range of the confidence interval (default is 95%)
summarySE <- function(data=NULL, measurevar, groupvars=NULL, na.rm=FALSE,
                      conf.interval=.95, .drop=TRUE) {
  library(plyr)
  
  # New version of length which can handle NA's: if na.rm==T, don't count them
  length2 <- function (x, na.rm=FALSE) {
    if (na.rm) sum(!is.na(x))
    else       length(x)
  }
  
  # This does the summary. For each group's data frame, return a vector with
  # N, mean, and sd
  datac <- ddply(data, groupvars, .drop=.drop,
                 .fun = function(xx, col) {
                   c(N    = length2(xx[[col]], na.rm=na.rm),
                     mean = mean   (xx[[col]], na.rm=na.rm),
                     sd   = sd     (xx[[col]], na.rm=na.rm)
                   )
                 },
                 measurevar
  )
  
  # Rename the "mean" column    
  datac <- rename(datac, c("mean" = measurevar))
  
  datac$se <- datac$sd / sqrt(datac$N)  # Calculate standard error of the mean
  
  # Confidence interval multiplier for standard error
  # Calculate t-statistic for confidence interval: 
  # e.g., if conf.interval is .95, use .975 (above/below), and use df=N-1
  ciMult <- qt(conf.interval/2 + .5, datac$N-1)
  datac$ci <- datac$se * ciMult
  
  return(datac)
}

t.test(Number_of_landings_of_the_birds ~ Drone_Falcon, data = landings)

summarylanding=summarySE(landings, measurevar="Number_of_landings_of_the_birds", groupvars=c("Drone_Falcon", "Species"))
summarylanding$Drone_Falcon=as.factor(summarylanding$Drone_Falcon)
summarylanding$Drone_Falcon=ordered(summarylanding$Drone_Falcon, levels = c("Falcon", "Drone"))

library(plyr)
summarylanding$Drone_Falcon=revalue(summarylanding$Drone_Falcon, c("Falcon"="RobotFalcon"))


a2=ggplot(subset(summarylanding,summarylanding$Species=="Corvids"), aes(x=Drone_Falcon, y=Number_of_landings_of_the_birds)) + 
  geom_bar(position=position_dodge(), colour="black", stat="identity") +
  scale_fill_manual(values=c("Black", "black"))+
  labs(title="",x="", y = "")+
  geom_errorbar(aes(ymin=Number_of_landings_of_the_birds-se, ymax=Number_of_landings_of_the_birds+se),
                width=.2,                    # Width of the error bars
                position=position_dodge(.9))+
  guides(fill=guide_legend(title="Deterrence method"))+
  theme_classic()+  scale_y_continuous(expand = c(0, 0), limits = c(0, 6))+
  theme(plot.title = element_text(size=15),
        axis.title.x=element_blank(),
        axis.text.x=element_text(size=11),
        axis.ticks.x=element_blank(),
        axis.text.y = element_text(size=11),
        axis.title.y = element_text(size=14))

b2=ggplot(subset(summarylanding,summarylanding$Species=="Gulls"), aes(x=Drone_Falcon, y=Number_of_landings_of_the_birds)) + 
  geom_bar(position=position_dodge(), colour="black", stat="identity") +
  scale_fill_manual(values=c("Black", "black"))+
  labs(title="",x="", y = "Number of landings (#)")+
  geom_errorbar(aes(ymin=Number_of_landings_of_the_birds-se, ymax=Number_of_landings_of_the_birds+se),
                width=.2,                    # Width of the error bars
                position=position_dodge(.9))+
  guides(fill=guide_legend(title="Deterrence method"))+
  theme_classic()+  scale_y_continuous(expand = c(0, 0), limits = c(0, 6))+
  theme(plot.title = element_text(size=15),
        axis.title.x=element_blank(),
        axis.text.x=element_text(size=11),
        axis.ticks.x=element_blank(),
        axis.text.y = element_text(size=11),
        axis.title.y = element_text(size=14))

c2=ggplot(subset(summarylanding,summarylanding$Species=="Starlings"), aes(x=Drone_Falcon, y=Number_of_landings_of_the_birds)) + 
  geom_bar(position=position_dodge(), colour="black", stat="identity") +
  scale_fill_manual(values=c("Black", "black"))+
  labs(title="",x="Deterrence method", y = "")+
  geom_errorbar(aes(ymin=Number_of_landings_of_the_birds-se, ymax=Number_of_landings_of_the_birds+se),
                width=.2,                    # Width of the error bars
                position=position_dodge(.9))+
  guides(fill=guide_legend(title="Deterrence method"))+
  theme_classic()+  scale_y_continuous(expand = c(0, 0), limits = c(0, 6))+
  theme(plot.title = element_text(size=15),
        axis.title.x=element_text(size=15),
        axis.text.x=element_text(size=11),
        axis.ticks.x=element_blank(),
        axis.text.y = element_text(size=11),
        axis.title.y = element_text(size=14))


summarylanding2=summarySE(landings, measurevar="Number_of_landings_of_the_birds", groupvars=c("Drone_Falcon"))
summarylanding2$Drone_Falcon=as.factor(summarylanding2$Drone_Falcon)
summarylanding2$Drone_Falcon=ordered(summarylanding2$Drone_Falcon, levels = c("Falcon", "Drone"))

#summarylanding2$Drone_Falcon=revalue(summarylanding2$Drone_Falcon, c("Falcon"="RobotFalcon (n=56)"))
#summarylanding2$Drone_Falcon=revalue(summarylanding2$Drone_Falcon, c("Drone"="Drone (n=56)"))
summarylanding2$Drone_Falcon=revalue(summarylanding2$Drone_Falcon, c("Falcon"="RobotFalcon"))



b=ggplot(summarylanding2, aes(x=Drone_Falcon, y=Number_of_landings_of_the_birds)) + 
  geom_bar(position=position_dodge(), colour="black", stat="identity") +
  scale_fill_manual(values=c("Black", "black"))+
  labs(title=""
       #Number of landings per flight"
       ,x="", y = "Number of landings per flight (#)")+
  geom_errorbar(aes(ymin=Number_of_landings_of_the_birds-se, ymax=Number_of_landings_of_the_birds+se),
                width=.2,                    # Width of the error bars
                position=position_dodge(.9))+
  guides(fill=guide_legend(title="Deterrence method"))+
  theme_classic()+  scale_y_continuous(expand = c(0, 0), limits = c(0, 5))+
  theme(plot.title = element_text(size=15),
        axis.title.x=element_text(size=15),
        axis.text.x=element_text(size=11),
        axis.ticks.x=element_blank(),
        axis.text.y = element_text(size=11),
        axis.title.y = element_text(size=14))


#######################################################################
################### Figure 3a #########################################
#######################################################################

#install.packages("pillar")

#install.packages("dplyr")
library(dplyr)

#install.packages("readxl")
library(readxl)

#install.packages("gridExtra")
library(gridExtra )

#install.packages("ggfortify")
#library(ggfortify)

#install.packages("survival")
library(survival)

#install.packages("survminer")
library(survminer)

#install.packages("gridExtra")
library(gridExtra )

library(grid)


TimeData<-read.table("Clear_times.txt", header = T)


TimeData2=TimeData

str(TimeData2)

TimeData2$Species=as.factor(TimeData2$Species)
#TimeData2$Away=as.numeric(TimeData2$Away)
TimeData2$Drone_Falcon=as.factor(TimeData2$Drone_Falcon)
#TimeData2$Initiation=as.factor(TimeData2$Initiation)
TimeData2$Drone_Falcon=as.factor(TimeData2$Drone_Falcon)
TimeData2$Flight_initiation_seconds=as.numeric(as.character(TimeData2$Flight_initiation_seconds))
TimeData2$Fly_away_seconds=as.numeric(as.character(TimeData2$Fly_away_seconds))


unique(TimeData2$Species)

fits <-survfit(Surv(Fly_away_seconds, Away) ~ Drone_Falcon, data = TimeData2)

fits

summary(fits)

surv_pvalue(fits)

survdiff(Surv(Fly_away_seconds, Away) ~ Drone_Falcon, data = TimeData2)
survdiff(Surv(Fly_away_seconds, Away) ~ Drone_Falcon, data = subset(TimeData2,TimeData2$Drone_Falcon!="Drone"))
survdiff(Surv(Fly_away_seconds, Away) ~ Drone_Falcon, data = subset(TimeData2,TimeData2$Drone_Falcon!="Falcon"))
survdiff(Surv(Fly_away_seconds, Away) ~ Drone_Falcon, data = subset(TimeData2,TimeData2$Drone_Falcon!="Control"))



subset(fits,fits$Type=="Drone")

#??2(2, N =136) = 70.7, p < .001.


g=ggsurvplot(subset(fits,fits$n > 20),#surv.median.line = "hv", 
             TimeData2,  fun="event",
             #facet.by = "Species")
             #title = "Survival plot on the time it takes to deter birds",
             xlab="Time till birds have fled (seconds)",
             ylab="Proportion sites without birds",
             legend.title = "Deterrence method",
             legend.labs = c("Control (n=26)","Drone (n=56)","RobotFalcon (n=54)"),
             conf.int = FALSE,
             xlim=c(0, 610),
             break.x.by=60,
             #pval=TRUE
             ) 



a=g$plot+scale_colour_manual(values = c("darkgrey","red","Black")) + theme_classic()+ 
  theme(
    #legend.position = "none", this makes the background white instead of grey
    axis.text.x = element_text(size=11),
    axis.text.y = element_text(size=11),
    axis.title.x = element_text(size=15),
    axis.title.y = element_text(size=15),
    #legend.position="bottom"
  )+ theme(legend.position=c(.7, .4)) +  scale_y_continuous(expand = c(0, 0), limits = c(0, 1))+
  scale_x_continuous(expand = c(0, NA))

lay=c(1,1,1,2)

#install.packages("cowplot")
library(cowplot)


#############################################################################
################### Figure 3a and b #########################################
#############################################################################


plot_grid(a, b, align = "v", nrow = 1, rel_widths = c(3/5, 2/5))


#######################################################################
##################### Figure s2a #######################################
#######################################################################


fits <-survfit(Surv(Fly_away_seconds, Away) ~ Drone_Falcon, 
               data = subset(TimeData2,(TimeData2$Species=="Gulls")
               ))

fits

#subset(fits,fits$n>20)

d=ggsurvplot(fits,#surv.median.line = "hv", 
             fun = "event",
             TimeData2, 
             #facet.by = "Species")
             title = "Gulls",
             xlab="",
             ylab="Proportion sites no birds",
             #legend="none",
             legend.title = "Method",
             legend.labs = c("Control (n=8)","Drone (n=19)","RobotFalcon (n=19)"),
             xlim=c(0, 600),
             conf.int = FALSE,
             break.x.by=60,
             pval=FALSE
) 

d2=d$plot+scale_colour_manual(values = c("darkgrey","red","Black")) + theme_classic()+  
  theme(
    #legend.position = "none", this makes the background white instead of grey
    axis.text.x = element_text(size=11),
    axis.text.y = element_text(size=11),
    axis.title.x = element_blank(),
    axis.title.y = element_text(size=14),
    #legend.position="bottom"
  )+ theme(legend.position=c(.8, .85))+  scale_y_continuous(expand = c(0, 0), limits = c(0, 1))+
  scale_x_continuous(expand = c(0, NA))



fits <-survfit(Surv(Fly_away_seconds, Away) ~ Drone_Falcon, 
               data = subset(TimeData2,(TimeData2$Species=="Starlings")
               ))

fits

#subset(fits,fits$n>20)

e=ggsurvplot(fits,#surv.median.line = "hv", 
             fun = "event",
             TimeData2, 
             #facet.by = "Species")
             title = "Starlings",
             xlab="Time (seconds)",
             ylab="",
             #legend="none",
             legend.title = "Method",
             legend.labs = c("Control (n=8)","Drone (n=18)","RobotFalcon (n=20)"),
             xlim=c(0, 600),
             break.x.by=60,
             conf.int = FALSE,
             pval=FALSE
) 

e2=e$plot+scale_colour_manual(values = c("darkgrey","red","Black")) + theme_classic()+  
  theme(
    #legend.position = "none", this makes the background white instead of grey
    axis.text.x = element_text(size=11),
    axis.text.y = element_text(size=11),
    axis.title.x = element_text(size=14),
    axis.title.y = element_text(size=14),
    #legend.position="bottom"
  )+ theme(legend.position=c(.8, .85)) +  scale_y_continuous(expand = c(0, 0), limits = c(0, 1))+
  scale_x_continuous(expand = c(0, NA))


fits <-survfit(Surv(Fly_away_seconds, Away) ~ Drone_Falcon, 
               data = subset(TimeData2,(TimeData2$Species=="Corvids")
               ))

fits

#subset(fits,fits$n>20)

f=ggsurvplot(fits,#surv.median.line = "hv",  
             fun = "event",
             TimeData2, 
             #facet.by = "Species")
             title = "Corvids",
             xlab="",
             ylab="",
             #legend="none",
             legend.title = "Method",
             legend.labs = c("Control (n=6)","Drone (n=19)","RobotFalcon (n=15)"),
             xlim=c(0, 600),
             break.x.by=60,
             conf.int = FALSE,
             pval=FALSE
) 

f2=f$plot+scale_colour_manual(values = c("darkgrey","red","Black")) + theme_classic()+  
  theme(
    #legend.position = "none", this makes the background white instead of grey
    axis.text.x = element_text(size=11),
    axis.text.y = element_text(size=11),
    axis.title.x = element_blank(),
    axis.title.y = element_text(size=14),
    #legend.position="bottom"
  )+ theme(legend.position=c(.8, .85))+  scale_y_continuous(expand = c(0, 0), limits = c(0, 1))+
  scale_x_continuous(expand = c(0, NA))

#######################################################################
##################### Figure s2a and b #######################################
#######################################################################

plot_grid(f2, a2, d2, b2, e2,c2, align = "v", nrow = 3, rel_widths = c(3/5, 2/5,3/5, 2/5,3/5, 2/5))


